{% extends "account/base.html" %}

{% load i18n %}
{% load account socialaccount %}
{% load bootstrap_tags %}

{% block head_title %}{% trans "Sign In" %}{% endblock %}

{% block content %}

<h1>{% trans "Sign In" %}</h1>

{% include "django_mailman3/login_extra_top.html" %}

{% get_providers as socialaccount_providers %}

{% if socialaccount_providers %}
<p>{% blocktrans with site.name as site_name %}Please sign in with one
of your existing third party accounts. Or, <a href="{{ signup_url }}">sign up</a>
for a {{ site_name }} account and sign in below:{% endblocktrans %}</p>

<p>{% blocktrans with site.name as site_name %}If you have a {{ site_name }}
account that you haven't yet linked to any third party account, you must log
in with your account's email address and password and once logged in, you can
link your third party accounts via the Account Connections tab on your user
profile page.{% endblocktrans %}</p>

<p>{% blocktrans with site.name as site_name %}If you do not have a
{{ site_name }} account but you have one of these third party accounts, you can
create a {{ site_name }} account and sign-in in one step by clicking the third
party account.{% endblocktrans %}</p>

<div class="socialaccount_ballot">

  <ul class="socialaccount_providers list-inline">
    {% include "socialaccount/snippets/provider_list.html" with process="login" %}
  </ul>

  {% include "django_mailman3/login_extra_post_providers.html" %}

  <div class="login-or">{% trans 'or' %}</div>

</div>

{% include "socialaccount/snippets/login_extra.html" %}

{% else %}
<p>{% blocktrans %}If you have not created an account yet, then please
<a href="{{ signup_url }}">sign up</a> first.{% endblocktrans %}</p>
{% endif %}

<form class="login form-horizontal" method="POST" action="{% url 'account_login' %}">
  {% bootstrap_form_horizontal form 2 4 %}
  {% if redirect_field_value %}
  <input type="hidden" name="{{ redirect_field_name }}" value="{{ redirect_field_value }}" />
  {% endif %}
  <div class="form-group">
    <div class="offset-md-2 col-md-4">
      <button class="btn btn-primary" type="submit">{% trans "Sign In" %}</button>
      &nbsp;
      <a href="{% url 'account_reset_password' %}">{% trans "Forgot Password?" %}</a>
    </div>
  </div>
</form>

{% endblock %}
